﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;

namespace _8xpto8xv
{
    class Program
    {
        const int TYPE_OFFSET = 59;
        const byte APPVAR_TYPE = 0x15;
        const ushort CHECKSUM_ADD = 0x0F;

        static void Main(string[] args)
        {
            BinaryReader fileIn;
            BinaryWriter fileOut;
            ushort length, checksum;

            // intro
            Console.ForegroundColor = ConsoleColor.DarkGreen;
            Console.WriteLine("8xpto8xv - by James Vernon - www.jvti.org");
            Console.ResetColor();

            // check number of arguments
            if (args.Length != 1)
            {
                Console.ForegroundColor = ConsoleColor.Yellow;
                Console.WriteLine("USAGE: 8xpto8xv <inputfile>");
                Console.WriteLine("eg. 8xpto8xv zab5e1f1");
                Console.ResetColor();
                return;
            }

            // open files
            fileIn = new BinaryReader(File.Open(args[0] + ".8xp", FileMode.Open));
            fileOut = new BinaryWriter(File.Open(args[0] + ".8xv", FileMode.Create));

            // copy header before var type
            fileOut.Write(fileIn.ReadBytes(TYPE_OFFSET));

            // read the var type, and write the new var type
            fileIn.ReadByte();
            fileOut.Write(APPVAR_TYPE);

            // copy more of the header, before the data length
            fileOut.Write(fileIn.ReadBytes(10));

            // get length of data, and write it to the output file as well
            length = fileIn.ReadUInt16();
            fileOut.Write(length);

            // write the data section
            fileOut.Write(fileIn.ReadBytes(length));

            // get checksum, increase it, and write it to the output file
            checksum = fileIn.ReadUInt16();
            checksum += CHECKSUM_ADD;
            fileOut.Write(checksum);

            // close files
            fileIn.Close();
            fileOut.Close();

            // success
            Console.ForegroundColor = ConsoleColor.White;
            Console.WriteLine("Success! Output file is " + args[0] + ".8xv");
            Console.ResetColor();
        }
    }
}
